# mammos-units

`mammos-units` is a units package built on top of the powerful Astropy units.
It provides additional functionality for magnetic units.

## Try it in the cloud
Try `mammos-units` without installing it locally by directly accessing it directly in the cloud
via Binder.
Simply click the badge to get started: [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/MaMMoS-project/units/latest?urlpath=%2Fdoc%2Ftree%2Fdocs%2Fexample.ipynb)

Sessions are temporary and may time out after a period of inactivity, and any files
created or modified during your session will not be saved.
To avoid losing your work, please remember to download any files you create or edit
before your session ends.

## Documentation

[A notebook with example usage is available](docs/example.ipynb), and can also 
[be explored interactively](https://mybinder.org/v2/gh/MaMMoS-project/units/latest?urlpath=%2Fdoc%2Ftree%2Fdocs%2Fexample.ipynb).

## Installation

To install `mammos-units`, you can use `pip install mammos-units` inside a Python environment.
